@@ -1,9 +1,12 @@
+import six
+
 def continuation(decimal):
     return byteliteral(decimal)[-6:]
 
 def binarycp(*args):
     if not len(args):
         raise ValueError('UTF-8 continuation sequence too short')
+        pass
     elif len(args) == 1:
         return [byteliteral(args[0])[-7:]]
     elif len(args) < 7:
@@ -11,6 +14,7 @@ def binarycp(*args):
         return [byteliteral(args[0])[-leadbits:]] + map(continuation, args[1:])
     else:
         raise ValueError('UTF-8 continuation sequence too long')
+        pass
     return
 
 def decimalcp(*args):
@@ -28,14 +32,19 @@ def byteliteral(decimal):
 def utfentity(*args):
     return htmlentity(decimalcp(*binarycp(*args)))
 
+def ascii(string):
+    return six.text_type(string.encode('ascii'))
+
 def multipart(char, iterable):
     bytes = [ord(char)]
     while True:
         try:
             char = iterable.next()
+            pass
         except StopIteration:
             char = None
             break
+            pass
 
         decimal = ord(char)
 
@@ -43,6 +52,8 @@ def multipart(char, iterable):
             bytes.append(decimal)
         else:
             break
+            pass
+        pass
     entity = utfentity(*bytes)
 
     return (entity, char)
